<?php

namespace App\Presenters;

use Nette,
	App\Model,
    Nette\Application\UI\Form;


/**
 * Base presenter for all application presenters.
 */
abstract class BasePresenter extends Nette\Application\UI\Presenter
{
    public $authorMsgUser = 'user';

    public function beforeRender()
    {
        if($this->user->loggedIn)
        {
            $this->template->loggedIn = true;
            $userId = $this->getUser()->getIdentity()->getId();
            $this->template->userId = $userId;
            $userData = $this->getUser()->getIdentity()->getData();
            $this->template->userData = $userData;

//            if (isset($userData['email']))
//            {
//                $this->context->housekeeper->setLastOnline($userId);
//            }
//            else
//            {
//
//            }
//            $this->template->username = $this->user->getIdentity()->
        }
        else
        {
            $this->template->loggedIn = false;
        }
    }

    protected function createComponentRegistration()
    {
        $form = new Form;
        $form->addText('name')
            ->setRequired("Zadejte prosím váše jméno.")
            ->addRule(Form::MIN_LENGTH, 'Zadejte prosím alespoň dva znaky.', 2);
        $form->addText('email')
            ->setRequired("Zadejte prosím váš e-mail.")
            ->addRule(Form::EMAIL, 'Zadejte prosím správný formát e-mailu.');
        $form->addText('phone')
            ->setRequired("Zadejte prosím váš telefon.")
            ->addRule(Form::PATTERN, 'Telefonní číslo není ve správném tvaru', '^[+]?[()/0-9. -]{9,}$');
        $form->addPassword('password')
            ->setRequired("Zadejte prosím heslo")
            ->addRule(Form::MIN_LENGTH, 'Heslo musí mít alespoň %d znaků', 8);
        $form->addSubmit('submit');

        // call method signInFormSucceeded() on success
        $form->onSuccess[] = array($this, 'registrationSucceeded');
        return $form;
    }

    public function registrationSucceeded(Form $form)
    {
        $values = $form->getValues();
        $inserted = $this->context->users->addUser($values);


        if ($inserted)
        {
            //$this->context->mails->sendMailRegistrationFirstComplete($insertedClient);
            $this->flashMessage('Uživatel byl úspěně registrován.','success');
            $this->redirect('this');
        }
        else
        {
            $this->flashMessage('Uživatel s tímto e-mailem již existuje.','danger');
            $this->redirect('this');
        }
    }

    /**
     * Sign-in form factory.
     * @return Nette\Application\UI\Form
     */
    protected function createComponentSignIn()
    {
        $form = new Form;
        $form->addText('email')->setRequired("Zadejte prosím váš e-mail.")->addRule(Form::EMAIL, 'Zadejte prosím správný formát e-mailu.');
        $form->addPassword('password')->setRequired("Zadejte prosím heslo")->addRule(Form::MIN_LENGTH, 'Heslo musí mít alespoň %d znaků', 8);
        $form->addCheckbox('remember');
        $form->addSubmit('submit');

        // call method signInFormSucceeded() on success
        $form->onSuccess[] = array($this, 'signInFormSucceeded');
        return $form;
    }


    public function signInFormSucceeded($form, $values)
    {
        if ($values->remember) {
            $this->getUser()->setExpiration('14 days', FALSE);
        } else {
            $this->getUser()->setExpiration('20 minutes', TRUE);
        }

        try {
            $this->getUser()->login($values->email, $values->password);
            $this->redirect('this');

        } catch (Nette\Security\AuthenticationException $e) {
            $form->addError($e->getMessage());
            $this->flashMessage($e->getMessage(),'danger');
        }
    }

    public function actionOut()
    {
        $this->getUser()->logout();
        $this->flashMessage('Odhlášení proběhlo úspěšně.');
        $this->redirect('Homepage:');
    }
}
