<?php

namespace App\Presenters;

use Nette,
	App\Model;
use Nette\Application\UI\Form;

/**
 * Upravy inzeratu presenter.
 */
class UpravitInzeratPresenter extends BasePresenter
{
    protected $params;
    private $categories;
    private $subcategories;
    private $make;
    private $model;
    private $area_level_1;
    private $conditions;
    private $owner;
    private $ad;

    public function beforeRender()
    {
        parent::beforeRender();

        if ($this->getUser()->getIdentity())
        {
            $this->owner = $userData = $this->getUser()->getIdentity()->getData();
            if (isset($userData['user_id'])) $this->template->userId = $userData['user_id'];
            else $this->template->userId = null;
        }
    }

	public function renderDefault($id)
	{
        if(!$this->user->loggedIn)
        {
            $this->flashMessage('Pokud chcete tento inzerát upravovat a jste vlastníkem inzerátu, nejprve se musíte přihlásit.','danger');
            $this->redirect('Homepage:default');
        }

        $this->ad = $this->context->ad->getAd($id);
        if ($this->ad['user_id'] != $this->owner['user_id'])
        {
            $this->flashMessage('Tento inzerát nemáte právo upravovat.','danger');
            $this->redirect('Homepage:default');
        }


        $this->template->ad = $this->ad;
        $this->template->imagesPath = $this->context->ad->getImages($this->ad);
	}

	protected function createComponentUpravit()
	{
        //$this->ad = $this->context->ad->getAd($id);

        $categories = $this->context->category->getCategories();
        $subcategories = $this->context->category->getSubCategories($this->ad['category_id']);
        $this->categories = array(""=>"Vyberte kategorii")+$categories;
        $this->subcategories = array("" => "Vyberte podkategorii")+$subcategories;

        $makes = $this->context->make->getMakes();
        $models = $this->context->model->getModelsByMake($this->ad['make_id']);
        $this->make = array(""=>"Vyberte značku")+$makes;
        $this->model = array("" => "Vyberte model")+$models;

        $this->area_level_1 = $this->context->filter->getAreaLevel1();
        $this->conditions = $this->context->filter->getCondition();

		$form = new Form;
        $form->addText('title')
            ->setDisabled(!$this->user->loggedIn)
            ->setRequired("Zadejte prosím titulek inzerátu.")
            ->setDefaultValue($this->ad['title']);
        $form->addText('price')
            ->setDisabled(!$this->user->loggedIn)
            ->setRequired("Zadejte prosím cenu.")
            ->setDefaultValue($this->ad['price']);
        $form->addCheckbox('negotiation')
            ->setDisabled(!$this->user->loggedIn)
            ->setValue($this->ad['negotiation']);
        $form->addText('brand')
            ->setDisabled(!$this->user->loggedIn)
            ->setRequired("Zadejte prosím výrobce dílu.")
            ->setDefaultValue($this->ad['brand']);
        $form->addSelect('condition')->setItems($this->conditions)
            ->setDisabled(!$this->user->loggedIn)
            ->setRequired('Zvolte prosím stav dílu.')
            ->setDefaultValue($this->ad['condition']);
        $form->addSelect('area_level_1')->setItems($this->area_level_1)
            ->setDisabled(!$this->user->loggedIn)
            ->setRequired('Zvolte prosím kraj.')
            ->setDefaultValue($this->ad['area_level_1']);
        $form->addSelect('category_id')->setItems($this->categories)
            ->setDisabled(!$this->user->loggedIn)
            ->setRequired('Zvolte prosím kategorii.')
            ->setDefaultValue($this->ad['category_id']);
        $form->addSelect('subcategory_id')->setItems($this->subcategories)
            ->setDisabled(!$this->user->loggedIn)
            ->setRequired('Zvolte prosím podkategorii.')
            ->setDefaultValue($this->ad['subcategory_id']);
        $form->addSelect('make_id')->setItems($this->make)
            ->setDisabled(!$this->user->loggedIn)
            ->setDefaultValue($this->ad['make_id']);
        $form->addSelect('model_id')->setItems($this->model)
            ->setDisabled(!$this->user->loggedIn)
            ->setDefaultValue($this->ad['model_id']);
		$form->addUpload('photo1')
            ->setDisabled(!$this->user->loggedIn)
			->addRule(Form::IMAGE, 'Fotografie musí být JPEG, PNG nebo GIF.')
			->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 1 MB.', 1024 * 1024);
        $form->addUpload('photo2')
            ->setDisabled(!$this->user->loggedIn)
            ->addRule(Form::IMAGE, 'Fotografie musí být JPEG, PNG nebo GIF.')
            ->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 1 MB.', 1024 * 1024);
        $form->addUpload('photo3')
            ->setDisabled(!$this->user->loggedIn)
            ->addRule(Form::IMAGE, 'Fotografie musí být JPEG, PNG nebo GIF.')
            ->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 1 MB.', 1024 * 1024);
        $form->addUpload('photo4')
            ->setDisabled(!$this->user->loggedIn)
            ->addRule(Form::IMAGE, 'Fotografie musí být JPEG, PNG nebo GIF.')
            ->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 1 MB.', 1024 * 1024);
        $form->addTextArea('text')
            ->setDisabled(!$this->user->loggedIn)
            ->setDefaultValue($this->ad['text']);
        $form->addSubmit('submit')
            ->setDisabled(!$this->user->loggedIn);
        $form->addHidden("ad_id")->setDefaultValue($this->ad['ad_id']);

		$form->onSubmit[] = array($this, 'upravitSucceeded');
		return $form;
	}

	public function upravitSucceeded(Form $form)
	{
        $values = $form->getValues();

        $model_id = $form->getHttpData($form::DATA_TEXT, 'model_id');
        $values['model_id'] = $model_id;

        $subcategory_id = $form->getHttpData($form::DATA_TEXT, 'subcategory_id');
        $values['subcategory_id'] = $subcategory_id;

        $this->context->ad->editAd($values['ad_id'], $values);

        $path = 'assets/images/ads/'.$values['ad_id'].'/';
        $stav = $this->context->uploader->uploadImage($values['photo1'], 'ad_img_1', $path);
        unset($values['photo1']);
        $stav = $this->context->uploader->uploadImage($values['photo2'], 'ad_img_2', $path);
        unset($values['photo2']);
        $stav = $this->context->uploader->uploadImage($values['photo3'], 'ad_img_3', $path);
        unset($values['photo3']);
        $stav = $this->context->uploader->uploadImage($values['photo4'], 'ad_img_4', $path);
        unset($values['photo4']);

        $this->redirect('Inzerat:default', $values['ad_id']);
	}


}
