<?php

namespace App\Model;

use Nette,
    Nette\Security\Passwords;

/**
 * Manage database table housekeeper
 *
 * @author Monsterboy
 */
class Ad extends Base
{
    protected $tableName = 'ad';
    public $database;
    protected $dateTime;
    protected $fav;
    protected $seen;

    function __construct(Nette\Database\Context $database, DateTime $dateTime, Favorite $fav, Seen $seen)
    {
        $this->database = $database;
        $this->dateTime = $dateTime;
        $this->fav = $fav;
        $this->seen = $seen;
    }

    /**
     * Ukládá nového inzerátu
     * 
     * @param array $values Hodnoty z formuláře
     * @return bool
     */
    public function addAd($userId, $value) {

            $valuesDB = array();
            $valuesDB['title'] = $value['title'];
            $valuesDB['text'] = $value['text'];
            $valuesDB['price'] = $value['price'];
            $valuesDB['negotiation'] = $value['negotiation'];
            $valuesDB['brand'] = $value['brand'];
            $valuesDB['model_id'] = $value['model_id'];
            $valuesDB['subcategory_id'] = $value['subcategory_id'];
            $valuesDB['category_id'] = $value['category_id'];
            $valuesDB['condition'] = $value['condition'];
            $valuesDB['user_id'] = $userId;
            $valuesDB['area_level_1'] = $value['area_level_1'];
            $valuesDB['created'] = date('Y-m-d H:i:s');

            $insertedId = $this->insert($valuesDB);
            return $insertedId;
    }

    public function remove($id)
    {
        $by['ad_id'] = $id;
        $values['removed'] = date('Y-m-d H:i:s');
        $this->update($by, $values);
    }

    /**
     *
     *
     * @param $count
     * @return mixed
     */
    public function getLastAds($count)
    {
        $rows = $this->database->query("SELECT ad.*, user.name AS username, category.name AS categoryname, make.name AS makename, model.name AS modelname
                                                  FROM ad 
                                                  LEFT JOIN user ON ad.user_id=user.user_id
                                                  LEFT JOIN category ON ad.category_id=category.category_id
                                                  LEFT JOIN make ON ad.make_id=make.make_id 
                                                  LEFT JOIN model ON ad.model_id=model.model_id
                                                  WHERE ad.removed = 0
                                                  ORDER BY ad.created DESC LIMIT $count");
        $params = array();
        while ($row = $rows->fetch())
        {
            $params[$row['ad_id']]['username'] = $row['username'];
            $params[$row['ad_id']]['categoryname'] = $row['categoryname'];
            $params[$row['ad_id']]['makename'] = $row['makename'];
            $params[$row['ad_id']]['modelname'] = $row['modelname'];
            $params[$row['ad_id']]['price'] = $row['price'];
            $params[$row['ad_id']]['title'] = $row['title'];
            $params[$row['ad_id']]['text'] = $row['text'];
            $params[$row['ad_id']]['negotiation'] = $row['negotiation'];
            $params[$row['ad_id']]['brand'] = $row['brand'];
            $params[$row['ad_id']]['created'] = $row['created'];
            $params[$row['ad_id']]['condition'] = $row['condition'];
            $params[$row['ad_id']]['area_level_1'] = $row['area_level_1'];
            $params[$row['ad_id']]['imagePath'] = $this->getPathImage($row['ad_id'], 1);

        }
        return $params;
    }

    public function getSimilarAds($category, $make, $model, $count)
    {
        if ($make != null) $makeWhere = "OR ad.make_id = $make";
        else $makeWhere ="";
        if ($model != null) $modelWhere = "OR ad.model_id = $model";
        else $modelWhere = "";

        $rows = $this->database->query("SELECT DISTINCT ad.*, user.name AS username, category.name AS categoryname, make.name AS makename, model.name AS modelname
                                                  FROM ad 
                                                  LEFT JOIN user ON ad.user_id=user.user_id
                                                  LEFT JOIN category ON ad.category_id=category.category_id
                                                  LEFT JOIN make ON ad.make_id=make.make_id 
                                                  LEFT JOIN model ON ad.model_id=model.model_id
                                                  WHERE ad.removed = 0 AND (ad.category_id = $category $makeWhere $modelWhere)
                                                  ORDER BY RAND() DESC LIMIT $count");

        $params = array();
        while ($row = $rows->fetch())
        {
            $params[$row['ad_id']]['username'] = $row['username'];
            $params[$row['ad_id']]['categoryname'] = $row['categoryname'];
            $params[$row['ad_id']]['makename'] = $row['makename'];
            $params[$row['ad_id']]['modelname'] = $row['modelname'];
            $params[$row['ad_id']]['price'] = $row['price'];
            $params[$row['ad_id']]['title'] = $row['title'];
            $params[$row['ad_id']]['text'] = $row['text'];
            $params[$row['ad_id']]['negotiation'] = $row['negotiation'];
            $params[$row['ad_id']]['brand'] = $row['brand'];
            $params[$row['ad_id']]['created'] = $row['created'];
            $params[$row['ad_id']]['condition'] = $row['condition'];
            $params[$row['ad_id']]['area_level_1'] = $row['area_level_1'];
            $params[$row['ad_id']]['imagePath'] = $this->getPathImage($row['ad_id'], 1);

        }
        return $params;
    }

    public function getAdsByIds($ids = null)
    {
        if ($ids == null)
        {
            return null;
        }

        $adsComaSeparated = implode(",",$ids);
        $rows = $this->database->query("SELECT ad.*, user.name AS username, category.name AS categoryname, make.name AS makename, model.name AS modelname
                                                  FROM ad 
                                                  LEFT JOIN user ON ad.user_id=user.user_id
                                                  LEFT JOIN category ON ad.category_id=category.category_id
                                                  LEFT JOIN make ON ad.make_id=make.make_id 
                                                  LEFT JOIN model ON ad.model_id=model.model_id
                                                  WHERE ad.removed = 0 and ad.ad_id IN ($adsComaSeparated)
                                                  ORDER BY ad.created DESC");
        $params = array();
        while ($row = $rows->fetch())
        {
            $params[$row['ad_id']]['username'] = $row['username'];
            $params[$row['ad_id']]['categoryname'] = $row['categoryname'];
            $params[$row['ad_id']]['makename'] = $row['makename'];
            $params[$row['ad_id']]['modelname'] = $row['modelname'];
            $params[$row['ad_id']]['price'] = $row['price'];
            $params[$row['ad_id']]['title'] = $row['title'];
            $params[$row['ad_id']]['text'] = $row['text'];
            $params[$row['ad_id']]['negotiation'] = $row['negotiation'];
            $params[$row['ad_id']]['brand'] = $row['brand'];
            $params[$row['ad_id']]['created'] = $row['created'];
            $params[$row['ad_id']]['condition'] = $row['condition'];
            $params[$row['ad_id']]['area_level_1'] = $row['area_level_1'];
            $params[$row['ad_id']]['imagePath'] = $this->getPathImage($row['ad_id'], 1);

        }
        return $params;
    }

    public function getAdsByUser($userId)
    {
        if ($userId == null)
        {
            return null;
        }

        $rows = $this->database->query("SELECT ad.*, user.name AS username, category.name AS categoryname, make.name AS makename, model.name AS modelname
                                                  FROM ad 
                                                  LEFT JOIN user ON ad.user_id=user.user_id
                                                  LEFT JOIN category ON ad.category_id=category.category_id
                                                  LEFT JOIN make ON ad.make_id=make.make_id 
                                                  LEFT JOIN model ON ad.model_id=model.model_id
                                                  WHERE ad.removed = 0 and ad.user_id = $userId
                                                  ORDER BY ad.created DESC");
        $params = array();
        while ($row = $rows->fetch())
        {
            $params[$row['ad_id']]['username'] = $row['username'];
            $params[$row['ad_id']]['categoryname'] = $row['categoryname'];
            $params[$row['ad_id']]['makename'] = $row['makename'];
            $params[$row['ad_id']]['modelname'] = $row['modelname'];
            $params[$row['ad_id']]['price'] = $row['price'];
            $params[$row['ad_id']]['title'] = $row['title'];
            $params[$row['ad_id']]['text'] = $row['text'];
            $params[$row['ad_id']]['negotiation'] = $row['negotiation'];
            $params[$row['ad_id']]['brand'] = $row['brand'];
            $params[$row['ad_id']]['created'] = $row['created'];
            $params[$row['ad_id']]['condition'] = $row['condition'];
            $params[$row['ad_id']]['area_level_1'] = $row['area_level_1'];
            $params[$row['ad_id']]['imagePath'] = $this->getPathImage($row['ad_id'], 1);

        }
        return $params;
    }

    /**
     * @param $id
     * @return FALSE|Nette\Database\Table\ActiveRow
     */
    public function getAd($id)
    {
        return $this->find($id);
    }

    /**
     * Edit params
     * 
     * @param integer $id ID of client
     * @param array $values values from form
     */
    public function editAd($id, $values)
    {
        $by['ad_id'] = $id;
        $this->update($by, $values);
    }

    /**
     * Return file path if file exist or return false
     *
     * @param $id
     * @return bool|string
     */
    public function getPathImage($id, $order)
    {
        $path = "assets/images/ads/".$id."/";
        $fileName = 'ad_img_'.$order;

        $fileTypes = array(1 => '.jpg', 2 => '.png', 3 => '.gif');
        foreach ($fileTypes as $fileType)
        {
            if (file_exists($path.$fileName.$fileType))
            {
                return "/".$path.$fileName.$fileType;
            }
        }

        return false;
    }

    /**
     * get images
     *
     * @param $adId
     * @return array
     */
    public function getImages($adId) {

        $dir = "assets/images/ads/".$adId."/";
        $images = scandir($dir);
        $pathImages = array();

        foreach ($images as $image) {

            if (($image != ".") AND ($image != "..")) $pathImages[] = "/".$dir.$image;
        }
        return $pathImages;
    }
}
