<?php

namespace App\Presenters;

use Nette,
	App\Model;
use Nette\Application\UI\Form;

/**
 * Homepage presenter.
 */
class AgencyPresenter extends BasePresenter
{
    public $params;

	public function renderRegistration()
	{
        if(!$this->user->loggedIn)
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
            $this->redirect('Sign:in');
        }

        $userId = $this->getUser()->getIdentity()->getId();
        /*
        $this->template->userId = $userId;
        $this->template->servicesAndCategories = $this->context->services->getServicesAndCategories();
        $this->template->availableServices = $this->context->housekeeper->getAvailableServicesId($userId);
        $this->template->params = $this->context->housekeeper->getProfileParams($userId);
        $this->template->profileImagePath = $this->context->housekeeper->getPathProfileImage($userId);*/
	}

	protected function createComponentRegistration()
	{
        $userId = $this->getUser()->getIdentity()->getId();
        $this->params = $this->context->agency->getAgencyParams($userId);

		$form = new Form;
		$form->addText('agency_name')
//            ->setValue($this->params->agency_name)
            ->setRequired("Zadejte prosím oficiální název agentury.");
		$form->addText('ic')
//            ->setValue($this->params->ic)
            ->setRequired("Zadejte prosím IČ.");
        $form->addText('dic')
//            ->setValue($this->params->ic)
            ->setRequired("Zadejte prosím DIČ.");
        $form->addText('contact_person_name')
//            ->setValue($this->params->contact_person_name)
            ->setRequired("Zadejte prosím jméno kontaktní osoby.");
        $form->addText('contact_person_phone')
//            ->setValue($this->params->contact_person_phone)
            ->setRequired("Zadejte prosím telefon na kontaktní osobu.")
            ->addRule(Form::PATTERN, 'Telefonní číslo není ve správném tvaru', '^[+]?[()/0-9. -]{9,}$');
        $form->addText('contact_person_email')
//            ->setValue($this->params->contact_person_email)
            ->setRequired("Zadejte prosím email kontaktní osoby.")
            ->addRule(Form::EMAIL, 'Zadejte prosím správný formát e-mailu.');
		$form->addText('street')
//            ->setValue($this->params->street)
            ->setRequired("Zadejte prosím vaši ulici");
		$form->addText('premise');
//            ->setValue($this->params->premise);
		$form->addText('street_number');
//            ->setValue($this->params->street_number);
		$form->addText('city')
//            ->setValue($this->params->city)
            ->setRequired('Zadejte prosím město');
		$form->addText('postcode')
//            ->setValue($this->params->postcode)
            ->setRequired('Zadejte prosím PSČ.');
		$form->addText('country')
//            ->setValue($this->params->country)
            ->setRequired("Zadejte prosím stát.");
        $form->addText('neighborhood');
//            ->setValue($this->params->neighborhood);
        $form->addText('sublocality_level_1');
//            ->setValue($this->params->sublocality_level_1);
        $form->addText('area_level_1');
//            ->setValue($this->params->area_level_1);
        $form->addText('area_level_2');
//            ->setValue($this->params->area_level_2);
        $form->addText('lat');
//            ->setValue($this->params->lat);
        $form->addText('lng');
//            ->setValue($this->params->lng);
        $form->addTextArea('description');
//            ->setValue($this->params->description);
        $form->addText('price_from');
//            ->setValue($this->params->price_from);
        $form->addText('price_to');
//            ->setValue($this->params->price_to);

        $form->addSubmit('submit');

		$form->onSubmit[] = array($this, 'registrationSucceeded');
		return $form;
	}

	public function registrationSucceeded(Form $form)
	{
        $values = $form->getValues();
        $userData = $this->getUser()->getIdentity()->getData();
        $housekeeperId = $this->getUser()->getIdentity()->getId();

        $agencyId = $this->context->agency->AddAgency($values);
        $this->context->agency->joinAgencyHousekeeper($housekeeperId, $agencyId);

        $this->redirect('Homepage:');
	}

    public function renderInfo()
    {
        if(!$this->user->loggedIn)
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
            $this->redirect('Sign:in');
        }

    }

    protected function createComponentInfo()
    {
        $userId = $this->getUser()->getIdentity()->getId();
        $data = $userData = $this->getUser()->getIdentity()->getData();
        $this->params = $this->context->agency->getAgencyParams($data['agency_id']);

        $form = new Form;
        $form->addText('agency_name')
            ->setValue($this->params->agency_name)
            ->setRequired("Zadejte prosím oficiální název agentury.");
        $form->addText('ic')
            ->setValue($this->params->ic)
            ->setRequired("Zadejte prosím IČ.");
        $form->addText('dic')
            ->setValue($this->params->ic)
            ->setRequired("Zadejte prosím DIČ.");
        $form->addText('contact_person_name')
            ->setValue($this->params->contact_person_name)
            ->setRequired("Zadejte prosím jméno kontaktní osoby.");
        $form->addText('contact_person_phone')
            ->setValue($this->params->contact_person_phone)
            ->setRequired("Zadejte prosím telefon na kontaktní osobu.")
            ->addRule(Form::PATTERN, 'Telefonní číslo není ve správném tvaru', '^[+]?[()/0-9. -]{9,}$');
        $form->addText('contact_person_email')
            ->setValue($this->params->contact_person_email)
            ->setRequired("Zadejte prosím email kontaktní osoby.")
            ->addRule(Form::EMAIL, 'Zadejte prosím správný formát e-mailu.');
        $form->addText('street')
            ->setValue($this->params->street)
            ->setRequired("Zadejte prosím vaši ulici");
        $form->addText('premise')
            ->setValue($this->params->premise);
        $form->addText('street_number')
            ->setValue($this->params->street_number);
        $form->addText('city')
            ->setValue($this->params->city)
            ->setRequired('Zadejte prosím město');
        $form->addText('postcode')
            ->setValue($this->params->postcode)
            ->setRequired('Zadejte prosím PSČ.');
        $form->addText('country')
            ->setValue($this->params->country)
            ->setRequired("Zadejte prosím stát.");
        $form->addText('neighborhood')
            ->setValue($this->params->neighborhood);
        $form->addText('sublocality_level_1')
            ->setValue($this->params->sublocality_level_1);
        $form->addText('area_level_1')
            ->setValue($this->params->area_level_1);
        $form->addText('area_level_2')
            ->setValue($this->params->area_level_2);
        $form->addText('lat')
            ->setValue($this->params->lat);
        $form->addText('lng')
            ->setValue($this->params->lng);
        $form->addTextArea('description')
            ->setValue($this->params->description);
        $form->addText('price_from')
            ->setValue($this->params->price_from);
        $form->addText('price_to')
            ->setValue($this->params->price_to);

        $form->addSubmit('submit');

        $form->onSubmit[] = array($this, 'infoSucceeded');
        return $form;
    }

    public function infoSucceeded(Form $form)
    {
        $values = $form->getValues();
        $userData = $this->getUser()->getIdentity()->getData();

        $agencyId = $this->context->agency->editAgency($userData['agency_id'], $values);

        $this->redirect('Homepage:');
    }

    public function renderHousekeepers()
    {
        $data = $userData = $this->getUser()->getIdentity()->getData();
        $this->template->results = $this->context->agency->getHousekeepers($data['agency_id']);
    }
}
