<?php

namespace App\Presenters;

use Nette,
	App\Model,
    Nette\Application\UI\Form;


/**
 * Homepage presenter.
 */
class HomepagePresenter extends BasePresenter
{
    private $categories;
    private $subcategories;
    private $make;
    private $model;
    private $area_level_1;
    private $conditions;
    private $priceFrom;
    private $priceTo;

    public function beforeRender()
    {
        parent::beforeRender();

        if ($this->getUser()->getIdentity()) {
            $userData = $this->getUser()->getIdentity()->getData();
            if (isset($userData['user_id'])) $this->template->userId = $userData['user_id'];
            else $this->template->userId = null;
        }
    }

	public function renderDefault()
	{
		$this->template->ads = $this->context->ad->getLastAds(3);

        $this->template->search = null;
		if($this->user->loggedIn) {
            $userData = $this->getUser()->getIdentity()->getData();
            $this->template->search = $dump = $this->context->search->getLastSearch($userData['user_id'], 3);
        }
	}

    protected function createComponentSearchByCar()
    {
        $makes = $this->context->make->getMakes();
        $this->make = array(""=>"Vyberte značku")+$makes;
        $this->model = array("" => "Prvně vyberte značku");

        $this->priceFrom = $this->context->filter->getPriceFrom();
        $this->priceTo = $this->context->filter->getPriceTo();
        $this->conditions = $this->context->filter->getCondition();

        $form = new Form;
        $form->addSelect('condition')->setItems($this->conditions);
        $form->addSelect('make')->setItems($this->make);
        $form->addSelect('model')->setItems($this->model);
        $form->addSelect('priceFrom')->setItems($this->priceFrom);
        $form->addSelect('priceTo')->setItems($this->priceTo);
        $form->addSubmit('submit');

        $form->onSubmit[] = array($this, 'searchByCarSucceeded');
        return $form;
    }

    public function searchByCarSucceeded(Form $form)
    {
        $values = $form->getValues();

        $model_id = $form->getHttpData($form::DATA_TEXT, 'model');
        $values['model'] = $model_id;

        $this->redirect('Listing:', $values);
    }

    protected function createComponentSearchByCategory()
    {
        $categories = $this->context->category->getCategories();
        $this->categories = array(""=>"Vyberte kategorii")+$categories;
        $this->subcategories = array("" => "Prvně vyberte Kategorii");

        $this->priceFrom = $this->context->filter->getPriceFrom();
        $this->priceTo = $this->context->filter->getPriceTo();
        $this->conditions = $this->context->filter->getCondition();

        $form = new Form;
        $form->addSelect('condition2')->setItems($this->conditions);
        $form->addSelect('category')->setItems($this->categories);
        $form->addSelect('subcategory')->setItems($this->subcategories);
        $form->addSelect('priceFrom2')->setItems($this->priceFrom);
        $form->addSelect('priceTo2')->setItems($this->priceTo);
        $form->addSubmit('submit2');

        $form->onSubmit[] = array($this, 'searchByCategorySucceeded');
        return $form;
    }

    public function searchByCategorySucceeded(Form $form)
    {
        $values = $form->getValues();
        //dump($values);

        $subcategory = $form->getHttpData($form::DATA_TEXT, 'subcategory');
        $values['subcategory'] = $subcategory;

        $this->redirect('Listing:', $values);
    }
}
