<?php

namespace App\Presenters;

use Nette,
	App\Model;
use Nette\Application\UI\Form;

/**
 * Homepage presenter.
 */
class HousekeeperPresenter extends BasePresenter
{
    public $profileId;
    public $agencyEncodeId;

    public function beforeRender()
    {
        parent::beforeRender();

        if ($this->getUser()->getIdentity())
        {
            $userData = $this->getUser()->getIdentity()->getData();
            if (isset($userData['user_id'])) $this->template->userId = $userData['user_id'];
            else $this->template->userId = null;

            if (isset($userData['agency_id'])) {
                $this->agencyEncodeId = $this->context->encodingString->base64url_encode($userData['agency_id']);
            } else {
                $this->agencyEncodeId = null;
            }
        }

    }

	public function renderDefault($id)
	{
        $this->profileId = $id;

        $this->template->author = $this->authorMsgUser;

        $this->template->params = $this->context->housekeeper->getProfileParams($this->profileId);
        $this->template->lastOnline = $this->context->housekeeper->getLastOnline($this->profileId);
        $this->template->age = $this->context->housekeeper->getAge($this->profileId);
        $this->template->profileImagePath = $this->context->housekeeper->getPathProfileImage($this->profileId);
        $this->template->servicesAndCategories = $this->context->services->getServicesAndCategories();
        $availableServices = $this->context->housekeeper->getAvailableServicesId($this->profileId);
        $this->template->availableServices = $availableServices;
        $this->template->rating = $this->context->housekeeper->getRating($this->profileId);
	}

    public function renderMessages()
    {
        if($this->user->loggedIn)
        {
            $userData = $this->getUser()->getIdentity()->getData();

            if (isset($userData['email']))
            {
                $this->profileId = $this->getUser()->getIdentity()->getId();
                $userData = $this->getUser()->getIdentity()->getData();

                if (isset($userData['agency_id'])) {
                    $this->agencyEncodeId = $this->context->encodingString->base64url_encode($userData['agency_id']);
                } else {
                    $this->agencyEncodeId = null;
                }

                $this->template->params = $this->context->housekeeper->getProfileParams($this->profileId);
                $this->template->profileImagePath = $this->context->housekeeper->getPathProfileImage($this->profileId);
                $this->template->messages = $this->context->messages->getConversationsHousekeeper($this->profileId);
                $this->template->author = $this->authorMsgHousekeeper;
                $this->template->agencyEncodeId = $this->agencyEncodeId;
            }
            else
            {
                $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit jako hospodyně.','warning');
                $this->redirect('Sign:in');
            }
        }
        else
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
            $this->redirect('Sign:in');
        }
    }

    public function renderConversation($userId)
    {
        if($this->user->loggedIn)
        {
            $userData = $this->getUser()->getIdentity()->getData();

            if (isset($userData['email']))
            {
                $this->profileId = $this->getUser()->getIdentity()->getId();
                $this->template->userId = $userId;
                $this->template->author = $this->authorMsgHousekeeper;

                $this->template->params = $this->context->housekeeper->getProfileParams($this->profileId);
                $this->template->profileImagePath = $this->context->housekeeper->getPathProfileImage($this->profileId);
                $this->template->messages = $this->context->messages->getConversation($userId, $this->profileId);

            }
            else
            {
                $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit jako hospodyně.','warning');
                $this->redirect('Sign:in');
            }
        }
        else
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
            $this->redirect('Sign:in');
        }
    }
}
