<?php

namespace App\Presenters;

use Nette,
	App\Model;
use Nette\Application\UI\Form;

/**
 * Homepage presenter.
 */
class ListingPresenter extends BasePresenter
{
    private $categories;
    private $subcategories;
    private $make;
    private $model;
    private $area_level_1;
    private $conditions;
    private $priceFrom;
    private $priceTo;

    public function beforeRender()
    {
        parent::beforeRender();

        if ($this->getUser()->getIdentity()) {
            $userData = $this->getUser()->getIdentity()->getData();
            if (isset($userData['user_id'])) $this->template->userId = $userData['user_id'];
            else $this->template->userId = null;
        }
    }

	public function renderDefault($p = array(), $o = array(), $page = 1, $a = array())
	{
        if($this->user->loggedIn) {
            $userData = $this->getUser()->getIdentity()->getData();
        } else {
            $userData['user_id'] = null;
        }

        //Setup třídy pro vyhledávání
        if (isset($p['make'])) $this->context->listing->setMake($p['make']);
        if (isset($p['model'])) $this->context->listing->setModel($p['model']);
        if (isset($p['priceFrom'])) $this->context->listing->setPriceFrom($p['priceFrom']);
        if (isset($p['priceTo'])) $this->context->listing->setPriceTo($p['priceTo']);
        if (isset($p['priceFrom2'])) $this->context->listing->setPriceFrom($p['priceFrom2']);
        if (isset($p['priceTo2'])) $this->context->listing->setPriceTo($p['priceTo2']);
        if (isset($p['condition'])) $this->context->listing->setCondition($p['condition']);
        if (isset($p['condition2'])) $this->context->listing->setCondition($p['condition2']);
        if (isset($p['category'])) $this->context->listing->setCategory($p['category']);
        if (isset($p['subcategory'])) $this->context->listing->setSubcategory($p['subcategory']);
        if (isset($userData['user_id'])) $this->context->listing->setUser($userData['user_id']);

        $this->template->areaSelected = array();
        if (count($a) > 0) {
            $this->context->listing->setAreaLevel1($a);
            $this->template->areaSelected = $a;
        }
        if (count($o) > 1) $this->context->listing->setOrderBy($o['by'], $o['sort']);

        //Stránkování
        $count = $this->context->listing->getAdsCount(); //Počet nalezených záznamů

        // Vyrobíme si instanci Paginatoru a nastavíme jej
        $paginator = new Nette\Utils\Paginator;
        $paginator->setItemCount($count); // celkový počet článků
        $paginator->setItemsPerPage(3); // počet položek na stránce
        $paginator->setPage($page); // číslo aktuální stránky

        //Nastavíme Limit a Offset pro stránkování
        $this->context->listing->setLimit($paginator->getLength());
        $this->context->listing->setOffset($paginator->getOffset());

        //Proměnné pro stránkování
        $this->template->paginator = $paginator;
        $this->template->p = $p;
        $this->template->o = $o;

        $ads = array();
        $ads = $this->context->listing->getAds();
        $this->template->results = $ads;
        $this->template->resultsCount = $count;

        $this->template->areas = $this->context->filter->getAreaLevel1();

        if($this->user->loggedIn)
        {
            $userData = $this->getUser()->getIdentity()->getData();
            $valuesDb = array();
            $valuesDb['user_id'] = $userData['user_id'];
            if (isset($p['make'])) $valuesDb['make_id'] = $p['make'];
            if (isset($p['model'])) $valuesDb['model_id'] = $p['model'];
            if (isset($p['category'])) $valuesDb['category_id'] = $p['category'];
            if (isset($p['subcategory'])) $valuesDb['subcategory_id'] = $p['subcategory'];
            if (isset($p['priceFrom'])) $valuesDb['price_from'] = $p['priceFrom'];
            if (isset($p['priceTo'])) $valuesDb['price_to'] = $p['priceTo'];
            if (isset($p['condition'])) $valuesDb['condition'] = $p['condition'];
            if (isset($p['priceFrom2'])) $valuesDb['price_from'] = $p['priceFrom2'];
            if (isset($p['priceTo2'])) $valuesDb['price_to'] = $p['priceTo2'];
            if (isset($p['condition2'])) $valuesDb['condition'] = $p['condition2'];

            $this->context->search->addSearch($valuesDb);
        }
	}

    public function renderSeller($id, $o = array(), $page = 1)
    {
        if($this->user->loggedIn) {
            $userData = $this->getUser()->getIdentity()->getData();
        } else {
            $userData['user_id'] = null;
        }

        //Setup třídy pro vyhledávání
        $this->context->listing->setSeller($id);
        if (count($o) > 1) $this->context->listing->setOrderBy($o['by'], $o['sort']);

        //Stránkování
        $count = $this->context->listing->getAdsCount(); //Počet nalezených záznamů

        // Vyrobíme si instanci Paginatoru a nastavíme jej
        $paginator = new Nette\Utils\Paginator;
        $paginator->setItemCount($count); // celkový počet článků
        $paginator->setItemsPerPage(10); // počet položek na stránce
        $paginator->setPage($page); // číslo aktuální stránky

        //Nastavíme Limit a Offset pro stránkování
        $this->context->listing->setLimit($paginator->getLength());
        $this->context->listing->setOffset($paginator->getOffset());

        //Proměnné pro stránkování
        $this->template->paginator = $paginator;
        $this->template->o = $o;

        //Proměnné prodejce
        $this->template->sellerId = $id;
        $this->template->seller = $this->context->users->getProfileParams($id);
        $this->template->rating = $this->template->rating = $this->context->ratings->getRating($id);

        $ads = array();
        $ads = $this->context->listing->getAds();
        $this->template->results = $ads;
        $this->template->resultsCount = $count;
    }

    public function renderFavorite()
    {
        if($this->user->loggedIn) {
            $userData = $this->getUser()->getIdentity()->getData();
            $favoriteIds = $this->context->favorite->getAll($userData['user_id']);
            $this->template->results = $this->context->ad->getAdsByIds($favoriteIds);

        }
        else
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
        }
    }

    public function actionRemoveFavorite($id)
    {
        if($this->user->loggedIn) {
            $this->context->favorite->remove($id);
            $this->redirect("Listing:favorite");
        }
        else
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
        }
    }

    /**
     * Set favorite ad
     *
     * @throws Nette\Application\AbortException
     */
    public function handleAddFavorite()
    {
        if($this->user->loggedIn)
        {
            $userData = $this->getUser()->getIdentity()->getData();
            $this->context->favorite->addFavorite($userData['user_id'], $_REQUEST['ad']);
            $success = array('success'=>'Uloženo');
            $this->sendResponse(new Nette\Application\Responses\JsonResponse($success));
        }
        else
        {
            $loginWarning = array('error'=>'Pro uložení do oblíbených se musíte přihlásit');
            $this->sendResponse(new Nette\Application\Responses\JsonResponse($loginWarning));
        }
    }

    public function renderHistory()
    {
        if($this->user->loggedIn) {
            $userData = $this->getUser()->getIdentity()->getData();
            $favoriteIds = $this->context->seen->getAll($userData['user_id']);
            $this->template->results = $this->context->ad->getAdsByIds($favoriteIds);

        }
        else
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
        }
    }

    public function renderMyAds()
    {
        if($this->user->loggedIn) {
            $userData = $this->getUser()->getIdentity()->getData();
            $this->template->results = $this->context->ad->getAdsByUser($userData['user_id']);
        }
        else
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
        }
    }

    public function actionRemoveAd($id)
    {
        if($this->user->loggedIn) {
            $this->context->ad->remove($id);
            $this->redirect("Listing:myAds");
        }
        else
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
        }
    }

    protected function createComponentSearchByCar()
    {
        $condition = null;
        $make = null;
        $model = null;
        $priceFrom = null;
        $priceTo = null;

        if (isset($_REQUEST['p']['condition'])) $condition = $_REQUEST['p']['condition'];
        if (isset($_REQUEST['p']['make'])) $make = $_REQUEST['p']['make'];
        if (isset($_REQUEST['p']['model'])) $model = $_REQUEST['p']['model'];
        if (isset($_REQUEST['p']['priceFrom'])) $priceFrom = $_REQUEST['p']['priceFrom'];
        if (isset($_REQUEST['p']['priceTo'])) $priceTo = $_REQUEST['p']['priceTo'];

        $makes = $this->context->make->getMakes();
        $models = $this->context->model->getModelsByMake($make);
        $this->make = array(""=>"Vyberte značku")+$makes;
        $this->model = array("" => "Prvně vyberte značku")+$models;

        $this->priceFrom = $this->context->filter->getPriceFrom();
        $this->priceTo = $this->context->filter->getPriceTo();
        $this->conditions = $this->context->filter->getCondition();

        $form = new Form;
        $form->addSelect('condition')
            ->setItems($this->conditions)
            ->setValue($condition);
        $form->addSelect('make')
            ->setItems($this->make)
            ->setValue($make);;
        $form->addSelect('model')
            ->setItems($this->model)
            ->setValue($model);
        $form->addSelect('priceFrom')
            ->setItems($this->priceFrom)
            ->setValue($priceFrom);
        $form->addSelect('priceTo')
            ->setItems($this->priceTo)
            ->setValue($priceTo);
        $form->addSubmit('submit');

        $form->onSubmit[] = array($this, 'searchByCarSucceeded');
        return $form;
    }

    public function searchByCarSucceeded(Form $form)
    {
        $values = $form->getValues();

        $model_id = $form->getHttpData($form::DATA_TEXT, 'model');
        $values['model'] = $model_id;

        $this->redirect('Listing:', $values);
    }

    protected function createComponentSearchByCategory()
    {
        $condition2 = null;
        $category = null;
        $subcategory = null;
        $priceFrom2 = null;
        $priceTo2 = null;

        if (isset($_REQUEST['p']['condition2'])) $condition2 = $_REQUEST['p']['condition2'];
        if (isset($_REQUEST['p']['category'])) $category = $_REQUEST['p']['category'];
        if (isset($_REQUEST['p']['subcategory'])) $subcategory = $_REQUEST['p']['subcategory'];
        if (isset($_REQUEST['p']['priceFrom2'])) $priceFrom2 = $_REQUEST['p']['priceFrom2'];
        if (isset($_REQUEST['p']['priceTo2'])) $priceTo2 = $_REQUEST['p']['priceTo2'];

        $categories = $this->context->category->getCategories();
        $subcategories = $this->context->category->getSubCategories($category);
        $this->categories = array(""=>"Vyberte kategorii")+$categories;
        $this->subcategories = array("" => "Prvně vyberte Kategorii")+$subcategories;
        $this->priceFrom = $this->context->filter->getPriceFrom();
        $this->priceTo = $this->context->filter->getPriceTo();
        $this->conditions = $this->context->filter->getCondition();

        $form = new Form;
        $form->addSelect('condition2')
            ->setItems($this->conditions)
            ->setValue($condition2);
        $form->addSelect('category')
            ->setItems($this->categories)
            ->setValue($category);
        $form->addSelect('subcategory')
            ->setItems($this->subcategories)
            ->setValue($subcategory);
        $form->addSelect('priceFrom2')
            ->setItems($this->priceFrom)
            ->setValue($priceFrom2);
        $form->addSelect('priceTo2')
            ->setItems($this->priceTo)
            ->setValue($priceTo2);
        $form->addSubmit('submit2');

        $form->onSubmit[] = array($this, 'searchByCategorySucceeded');
        return $form;
    }

    public function searchByCategorySucceeded(Form $form)
    {
        $values = $form->getValues();
        //dump($values);

        $subcategory = $form->getHttpData($form::DATA_TEXT, 'subcategory');
        $values['subcategory'] = $subcategory;

        $this->redirect('Listing:', $values);
    }

    protected function createComponentSort()
    {

        $sort = array("created:DESC"=>"Nejnovější","created:ASC"=>"Nejstarší","price:ASC"=>"Nejlevnější","price:DESC"=>"Nejdražší");

        $sortSelected = null;
        if (isset($_REQUEST['o'])) {
            $sortSelected = $_REQUEST['o']['by'].":".$_REQUEST['o']['sort'];
        }

        $form = new Form;
        $form->addSelect('sort')
            ->setItems($sort)
            ->setValue($sortSelected);
        $form->addSubmit('submit3');

        $form->onSubmit[] = array($this, 'sortSucceeded');
        return $form;
    }

    public function sortSucceeded(Form $form)
    {
        $values = $form->getValues();
        $sort = explode(":",$values['sort']);
        $o['o']['by'] = $sort[0];
        $o['o']['sort'] = $sort[1];
        //dump($_REQUEST['p']);
        //dump($o);

        $this->redirect('this', $o);
        //$this->redirect('Listing:', $_REQUEST['p'], $o);
    }

    protected function createComponentArea()
    {

        $form = new Form;
        $form->addSubmit('submit4');

        $form->onSubmit[] = array($this, 'areaSucceeded');
        return $form;
    }

    public function areaSucceeded(Form $form)
    {
        $a['a'] = $form->getHttpData($form::DATA_TEXT, 'area[]');
        $this->redirect('this', $a);
    }
}
