<?php

namespace App\Presenters;

use Nette,
	App\Model;
use Nette\Application\UI\Form;

/**
 * User presenter.
 */
class UserPresenter extends BasePresenter
{
    public $userId;

    public function beforeRender()
    {
        parent::beforeRender();

        if(!$this->user->loggedIn)
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
            $this->redirect('Sign:in');
        }

        $userId = $this->getUser()->getIdentity()->getId();

        $this->template->profileImagePath = $this->context->users->getPathProfileImage($userId);
    }

    public function renderDefault()
    {
        if(!$this->user->loggedIn)
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
            $this->redirect('Sign:in');
        }

        $userId = $this->getUser()->getIdentity()->getId();

        $this->template->userId = $userId;
        $this->template->params = $this->context->users->getProfileParams($userId);
    }

    protected function createComponentRegistration()
    {
        $userId = $this->getUser()->getIdentity()->getId();
        $this->params = $this->context->users->getProfileParams($userId);

        $form = new Form;
        $form->addText('name')
            ->setValue($this->params->name)
            ->setRequired("Zadejte prosím vaše jméno.");
        $form->addText('surname')
            ->setValue($this->params->surname)
            ->setRequired("Zadejte prosím vaše příjmení.");
//        $form->addText('phone')
//            ->setValue($this->params->phone)
//            ->setRequired("Zadejte prosím váš telefon.")->addRule(Form::PATTERN, 'Telefonní číslo není ve správném tvaru', '^[+]?[()/0-9. -]{9,}$');
//        $form->addCheckbox('show_phone');
        $form->addUpload('photo')
            ->addRule(Form::IMAGE, 'Fotografie musí být JPEG, PNG nebo GIF.')
            ->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 1 MB.', 1024 * 1024);
        $form->addText('street')
            ->setValue($this->params->street)
            ->setRequired("Zadejte prosím vaši ulici");
        $form->addText('premise')
            ->setValue($this->params->premise);
        $form->addText('street_number')
            ->setValue($this->params->street_number);
        $form->addText('city')
            ->setValue($this->params->city)
            ->setRequired('Zadejte prosím město');
        $form->addText('postcode')
            ->setValue($this->params->postcode)
            ->setRequired('Zadejte prosím PSČ.');
        $form->addText('country')
            ->setValue($this->params->country)
            ->setRequired("Zadejte prosím stát.");
        $form->addText('neighborhood')
            ->setValue($this->params->neighborhood);
        $form->addText('sublocality_level_1')
            ->setValue($this->params->sublocality_level_1);
        $form->addText('area_level_1')
            ->setValue($this->params->area_level_1);
        $form->addText('area_level_2')
            ->setValue($this->params->area_level_2);
        $form->addText('lat')
            ->setValue($this->params->lat);
        $form->addText('lng')
            ->setValue($this->params->lng);

        $form->addSubmit('submit');

        $form->onSubmit[] = array($this, 'registrationSucceeded');
        return $form;
    }

    public function registrationSucceeded(Form $form)
    {
        $values = $form->getValues();
        $id = $this->getUser()->getIdentity()->getId();

        $stav = $this->context->uploader->uploadImage($values['photo'], 'user_'.$id, 'assets/images/users/');
        unset($values['photo']);

        $this->context->users->editUser($id, $values);

        $this->redirect('User:');
    }

    public function renderMessages()
    {
        if($this->user->loggedIn)
        {
            $userData = $this->getUser()->getIdentity()->getData();

            if (isset($userData['username']))
            {
                $this->userId = $this->getUser()->getIdentity()->getId();

                $this->template->params = $this->context->users->getProfileParams($this->userId);
                $this->template->messages = $this->context->messages->getConversationsUser($this->userId);
                $this->template->author = $this->authorMsgUser;
            }
            else
            {
                $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
                $this->redirect('Sign:in');
            }
        }
        else
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
            $this->redirect('Sign:in');
        }
    }

    public function renderConversation($housekeeperId)
    {
        if($this->user->loggedIn)
        {
            $userData = $this->getUser()->getIdentity()->getData();

            if (isset($userData['username']))
            {
                $this->userId = $this->getUser()->getIdentity()->getId();
                $this->template->housekeeperId = $housekeeperId;
                $this->template->author = $this->authorMsgUser;

                $this->template->params = $this->context->users->getProfileParams($this->userId);
                $this->template->messages = $this->context->messages->getConversation($this->userId, $housekeeperId);

            }
            else
            {
                $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit jako klient.','warning');
                $this->redirect('Sign:in');
            }
        }
        else
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
            $this->redirect('Sign:in');
        }
    }
}
